===============
pydeck-overlays
===============


.. image:: https://img.shields.io/pypi/v/pydeck_overlays.svg
        :target: https://pypi.python.org/pypi/pydeck_overlays

.. image:: https://img.shields.io/travis/oceanum-io/pydeck_overlays.svg
        :target: https://travis-ci.org/oceanum-io/pydeck_overlays

.. image:: https://readthedocs.org/projects/pydeck-overlays/badge/?version=latest
        :target: https://pydeck-overlays.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Pydeck layers for gridded data


* Free software: MIT license
* Documentation: https://pydeck-overlays.readthedocs.io.


Features
--------

* Pydeck layers for gridded data
* Layers for pcolor, vector particle flows, image overlayss and contours
* Use xarray datasets as input data

